smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon

# ``smartcard`.`pyro`.`server`.`PyroDaemon`.`PyroDaemon`.`_PyroDaemon``

class documentation

`class _PyroDaemon:`

View In Hierarchy

The pyro daemon actual wrapper class.

A single instance of this class is created by the public PyroDaemon class.

Method | `__call__` | Ctrl+c handler that will gracefully shutdown the server upon Ctrl+C signal
Method | `__init__` | Undocumented
Method | `connect` | Undocumented
Method | `disconnect` | Undocumented
Method | `start` | start pyro daemon.
Instance Variable | `daemon` | Undocumented
Instance Variable | `handler` | Undocumented

def __call__(self, signame, sf):

Ctrl+c handler that will gracefully shutdown the server upon Ctrl+C signal

def __init__(self):

Undocumented

def connect(self, object, name=None):

Undocumented

def disconnect(self, object):

Undocumented

def start(self):

start pyro daemon.

daemon =

Undocumented

handler =

Undocumented